@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03080300
+#define LIBXL_VERSION 0x03080601
 
 #ifdef _UNICODE
 
@@ -94,6 +94,8 @@
     #define xlSheetWriteError xlSheetWriteErrorW
     #define xlSheetColWidth xlSheetColWidthW
     #define xlSheetRowHeight xlSheetRowHeightW
+    #define xlSheetColWidthPx xlSheetColWidthPxW
+    #define xlSheetRowHeightPx xlSheetRowHeightPxW
     #define xlSheetSetCol xlSheetSetColW
     #define xlSheetSetRow xlSheetSetRowW
     #define xlSheetRowHidden xlSheetRowHiddenW
@@ -393,6 +395,8 @@
     #define xlSheetWriteError xlSheetWriteErrorA
     #define xlSheetColWidth xlSheetColWidthA
     #define xlSheetRowHeight xlSheetRowHeightA
+    #define xlSheetColWidthPx xlSheetColWidthPxA
+    #define xlSheetRowHeightPx xlSheetRowHeightPxA
     #define xlSheetSetCol xlSheetSetColA
     #define xlSheetSetRow xlSheetSetRowA
     #define xlSheetRowHidden xlSheetRowHiddenA
